# New in 0.14.4 (2021-11-16)

Bug fixes, some tutorial improvements.

## Changes

-   `kl_weight` handling for Pyro-based models ([#1242]).
-   Allow override of missing protein inference in {class}`~scvi.model.TOTALVI` ([#1251]). This allows to treat all 0s in a particular batch for one protein as biologically valid.
-   Fix load documentation (e.g., {meth}`~scvi.model.SCVI.load`, {meth}`~scvi.model.TOTALVI.load`) ([#1253]).
-   Fix model history on load with Pyro-based models ([#1255]).
-   Model construction tutorial uses new static setup anndata ([#1257]).
-   Add codebase overview figure to docs ([#1231]).

## Contributors

-   [@adamgayoso]
-   [@jjhong922]
-   [@watiss]

[#1231]: https://github.com/YosefLab/scvi-tools/pull/1231
[#1242]: https://github.com/YosefLab/scvi-tools/pull/1242
[#1251]: https://github.com/YosefLab/scvi-tools/pull/1251
[#1253]: https://github.com/YosefLab/scvi-tools/pull/1253
[#1255]: https://github.com/YosefLab/scvi-tools/pull/1255
[#1257]: https://github.com/YosefLab/scvi-tools/pull/1257
[@adamgayoso]: https://github.com/adamgayoso
[@jjhong922]: https://github.com/jjhong922
[@watiss]: https://github.com/watiss
